########
# cohort

legislator.id <- sort(unique(legislator.ID))
first.term <- tapply(session,legislator.ID,min)
first.term.ext <- first.term[match(data.use[,"legislator.ID"],legislator.id)]

ATE.b <- ATE.se <- matrix(NA,17,5)
for(p in 1:17){
  period <- first.term.ext==p+2
  for (v in c(1:5)){
    ols.out <- glm(dv[period,v] ~ purged.treatment.received.md[period] + seniority.md[period] -1,x=T,y=T)
    ATE.b[p,v] <- ols.out$coef[1]
    ols.out.block1 <- robust.se.2sls(ols.out,block1[period],prospective.candidacy.md[period])
    ols.out.block2 <- robust.se.2sls(ols.out,block2[period],prospective.candidacy.md[period])
    ols.out.block3 <- robust.se.2sls(ols.out,block3[period],prospective.candidacy.md[period])
    ATE.se[p,v] <- sqrt((ols.out.block1+ols.out.block2 - ols.out.block3)[1,1])  
  }
}

var.name <- c("Days of Attendance","Days of Speech","Letters in Speech", "Speech per Attendance","Speech Letters-per-Day")
period <- c(1:17)*3+1953

plot.data <- NULL
for(v in c(1:5)){
  temp.data <- data.frame(period,
                          ate.point=ATE.b[,v],
                          ate.ub=ATE.b[,v]+(1.96*ATE.se[,v]),
                          ate.lb=ATE.b[,v]-(1.96*ATE.se[,v]),
                          ul=ifelse(max(ATE.b[,v]+(1.96*ATE.se[,v]))>0,max(ATE.b[,v]+(1.96*ATE.se[,v])),0),
                          ll=ifelse(min(ATE.b[,v]-(1.96*ATE.se[,v]))<0,min(ATE.b[,v]-(1.96*ATE.se[,v])),0),
                          rect.max=ATE.baseline[v,1]+(1.96*ATE.baseline[v,2]),
                          rect.min=ATE.baseline[v,1]-(1.96*ATE.baseline[v,2]),
                          rect.med=ATE.baseline[v,1],
                          var.name=var.name[v]
  )
  plot.data <- rbind(plot.data,temp.data)
}

g <- ggplot(plot.data,aes(y=ate.point,x=period))
g + geom_ribbon(aes(x=period,ymax=rect.max,ymin=rect.min),alpha=.2)+ 
  geom_line(aes(x=period,y=rect.med),alpha=.4)+ 
  geom_line() +
  geom_line(aes(x=period,y=ate.ub),linetype='dashed') + 
  geom_line(aes(x=period,y=ate.lb),linetype='dashed') +
  geom_blank(aes(ymax=ul,ymin=ll)) +
  facet_wrap(~var.name,scale='free',ncol=2)+theme_bw()+
  geom_blank(aes(xmax=2004,xmin=1956)) +
  scale_y_continuous("Average Treatment Effects")+scale_x_continuous("Year")
#ggsave('result/cohort.jpg',width=8,height=8,dpi=200)
ggsave('../result/cohort.pdf',width=8,height=8)

write.csv(ATE.b,"../result/ATE.b.csv")
write.csv(ATE.se,"../result/ATE.se.csv")
