###############################################################
# Replicatiion File
# of
# "The Effects of Election Proximity on Participatory Shirking:
# The Staggered-Term Chamber as A Laboratory"
# Legislative Studies Quarterly 40 (4): 599-625
# by
# Kentaro Fukumoto (Kentaro.Fukumoto@gakushuin.ac.jp)
# and
# Akitaka Matsuo (akitaka.matsuo@nuffield.ox.ac.uk)
###############################################################

# You should install "ggplot2" package.

setwd("code")  
source("setup.r")

############################
# Regular Legislator Dataset

source("regular.legislator.r")

# 3,748 regular legislators
length(at.the.end.of.the.term)

# 468 irregular legislators
length(data.use.irregular$at.the.end.of.the.term)

# "Compliers, or those seeking reelection, make up 1,393 (76.8%) of 1,813 assigned-to-treatment observations, 
# none of 1,935 assigned-to-control observations plan to run."
# 1,813 assigned-to-treatment observations
table(at.the.end.of.the.term)[2]
# 1,393 (76.8%) compliers
table(at.the.end.of.the.term,prospective.candidacy)[2,2]
round(prop.table(table(at.the.end.of.the.term,prospective.candidacy),1)*100,1)[2,2]
# 1,935 assigned-to-control observations 
table(at.the.end.of.the.term)[1]
# none plan to run.
table(at.the.end.of.the.term,prospective.candidacy)[1,2]

# "94 (6.7%) of 1,393 legislators who planned to run for reelection in winter
# eventually failed to do so in summer
# just 18 (4.3%) of 420 councilors who did not intend to seek reelection before the pre-election session
# actually did so in the end."
# 94 (6.7%) legislators failed to run for reelection in summer
table(prospective.candidacy,actual.candidacy)[2,1]
round(prop.table(table(prospective.candidacy,actual.candidacy),1)*100,1)[2,1]
# 18 (4.3%) councilors seek reelection in the end
table(prospective.candidacy,actual.candidacy)[1,2]
round(prop.table(table(prospective.candidacy,actual.candidacy),1)*100,1)[1,2]

# 49 independent legislators
table.party.ID <- table(party.ID)
table.party.ID["999"]

source("block.legislator.1st.r")
## basic statistics
source("basic.statistics.r")
# block 1
# 1,092 legislator blocks
length(unique(block1))
# Except for blocks with only one observation (148 legislator blocks)
table(table(block1))[1]
# one legislator block with two observations do not have 
# both assigned-to-treatment and assigned-to-control observations
sum(c(
table(count1.no.control[,3])[-1],
table(count1.no.treat[,3])[-1]))

# block 2
# 1,547 district-year-party blocks
length(unique(block2))
# Except for blocks with only one observation (800 district-year-party blocks)
table(table(block2))[1]
# 29 district-year-party blocks with two or three observations
# both assigned-to-treatment and assigned-to-control observations
sum(c(table(count2.no.control[,3])[-1],table(count2.no.treat[,3])[-1]))

# Table 3
source("balance.check.r")
source("balance.check.regular.r")
round(balance.test.regular.binary,3)
round(balance.test.regular,3)
# balance check after observations with missing value(s) are dropped
# attend day
sum(attend.day==0)
round(balance.test.regular.no.attend,3)
# speak day
sum(speak.day==0)
round(balance.test.regular.no.speak,3)
# omission of missing values does not change the results
# files are fed to the "result" directory

# Model 1 of Table 4 (and Table A1)
source("do.mean.differencing.r")
source("model1.r")
round(ATE.baseline[1:5,],3)
# the numbers of observations
obs.regular

# Model 2 of Table 4
source("model2.r")
round(YonT,3)

# Model 3 of Table 4
source("model3.r")
round(YonTdumR,3)

# Figure 1
# Figure 2
source("figures.r")
dev.off()##
# files are fed to the "result" directory

# Appendix
source("appendix.r")
# Table A3
round(summary.statistics,3)
# Figure A1
# files are fed to the "result" directory

# Models 6 and 7 of Table A1
source("model6&7.r")
round(ATE.national,3)
round(ATE.prefectural,3)
# the numbers of observations
obs.prefectural
obs.national

##############################
# The Other Order Blocking

# Model 5 Table A1
source("model5.r")
round(ATE.other.order.block,3)

# Table A1
source("tableA1.r")
round(table.A1,3)

##############################
# Irregular Legislator Dataset

# Model 4
source("irregular.legislator.r")
# 3,748 regular legislators + 468 irregular legislators
length(at.the.end.of.the.term)
source("block.legislator.1st.r")
source("do.mean.differencing.r")
source("model4.r")
round(ATE.irregular,3)
# the numbers of observations
obs.irregular

# Table 4
source("table4.r")
round(table.ATE,3)

# Table A2
source("tableA2.r")
round(table.FT,3)

# Table A4
source("balance.check.r")
source("balance.check.irregular.r")
round(balance.test.irregular.binary,3)
round(balance.test.irregular,3)
# balance check when missing value observations are dropped
# attend day
sum(attend.day==0)
round(balance.test.irregular.no.attend,3)
# speak day
sum(speak.day==0)
round(balance.test.irregular.no.speak,3)
# anyway, nothing changes
# files are fed to the "result" directory

